@@ -360,14 +360,7 @@ void button_press_cb(GtkWidget *w, GdkEventButton *event, gpointer data)
 
 	if (xmms_running)
 	{
-		if (event->button == 2)
-		{
-			if(audacious_remote_is_pl_win(dbus_proxy))
-				audacious_remote_pl_win_toggle(dbus_proxy, FALSE);
-			else
-				audacious_remote_pl_win_toggle(dbus_proxy, TRUE);
-		}
-		else if (event->button == 3)
+		if ((event->button == 2) || (event->button == 3))
 		{
 			if(audacious_remote_is_main_win(dbus_proxy))
 				audacious_remote_main_win_toggle(dbus_proxy, FALSE);
